# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/Tick.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Timestamp_pb2 as rst_dot_timing_dot_Timestamp__pb2
from rst.timing import Duration_pb2 as rst_dot_timing_dot_Duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/Tick.proto',
  package='rst.cbse',
  syntax='proto2',
  serialized_pb=_b('\n\x13rst/cbse/Tick.proto\x12\x08rst.cbse\x1a\x1arst/timing/Timestamp.proto\x1a\x19rst/timing/Duration.proto\"\xd3\x01\n\x04Tick\x12\x17\n\x0fsequence_number\x18\x01 \x02(\r\x12(\n\ttimestamp\x18\x02 \x02(\x0b\x32\x15.rst.timing.Timestamp\x12\x30\n\x11virtual_timestamp\x18\x03 \x01(\x0b\x32\x15.rst.timing.Timestamp\x12&\n\x08timestep\x18\x04 \x01(\x0b\x32\x14.rst.timing.Duration\x12.\n\x10virtual_timestep\x18\x05 \x01(\x0b\x32\x14.rst.timing.DurationB\nB\x08TickType')
  ,
  dependencies=[rst_dot_timing_dot_Timestamp__pb2.DESCRIPTOR,rst_dot_timing_dot_Duration__pb2.DESCRIPTOR,])




_TICK = _descriptor.Descriptor(
  name='Tick',
  full_name='rst.cbse.Tick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='rst.cbse.Tick.sequence_number', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.cbse.Tick.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='virtual_timestamp', full_name='rst.cbse.Tick.virtual_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestep', full_name='rst.cbse.Tick.timestep', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='virtual_timestep', full_name='rst.cbse.Tick.virtual_timestep', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=300,
)

_TICK.fields_by_name['timestamp'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
_TICK.fields_by_name['virtual_timestamp'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
_TICK.fields_by_name['timestep'].message_type = rst_dot_timing_dot_Duration__pb2._DURATION
_TICK.fields_by_name['virtual_timestep'].message_type = rst_dot_timing_dot_Duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Tick'] = _TICK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tick = _reflection.GeneratedProtocolMessageType('Tick', (_message.Message,), dict(
  DESCRIPTOR = _TICK,
  __module__ = 'rst.cbse.Tick_pb2'
  # @@protoc_insertion_point(class_scope:rst.cbse.Tick)
  ))
_sym_db.RegisterMessage(Tick)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010TickType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/communicationpatterns/ResourceAllocation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Interval_pb2 as rst_dot_timing_dot_Interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/communicationpatterns/ResourceAllocation.proto',
  package='rst.communicationpatterns',
  syntax='proto2',
  serialized_pb=_b('\n2rst/communicationpatterns/ResourceAllocation.proto\x12\x19rst.communicationpatterns\x1a\x19rst/timing/Interval.proto\"\xca\x05\n\x12ResourceAllocation\x12\n\n\x02id\x18\n \x02(\t\x12\x42\n\x05state\x18\x14 \x02(\x0e\x32\x33.rst.communicationpatterns.ResourceAllocation.State\x12H\n\x08priority\x18\x1e \x02(\x0e\x32\x36.rst.communicationpatterns.ResourceAllocation.Priority\x12J\n\tinitiator\x18( \x02(\x0e\x32\x37.rst.communicationpatterns.ResourceAllocation.Initiator\x12\x44\n\x06policy\x18\x32 \x02(\x0e\x32\x34.rst.communicationpatterns.ResourceAllocation.Policy\x12\"\n\x04slot\x18< \x02(\x0b\x32\x14.rst.timing.Interval\x12)\n\x0b\x63onstraints\x18\x46 \x01(\x0b\x32\x14.rst.timing.Interval\x12\x14\n\x0cresource_ids\x18P \x03(\t\x12\x13\n\x0b\x64\x65scription\x18Z \x01(\t\"l\n\x05State\x12\r\n\tREQUESTED\x10\n\x12\r\n\tSCHEDULED\x10\x14\x12\x0c\n\x08REJECTED\x10\x1e\x12\r\n\tCANCELLED\x10(\x12\r\n\tALLOCATED\x10\x32\x12\x0b\n\x07\x41\x42ORTED\x10<\x12\x0c\n\x08RELEASED\x10\x46\"L\n\x08Priority\x12\x06\n\x02NO\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\n\n\x06NORMAL\x10\x02\x12\x08\n\x04HIGH\x10\x03\x12\n\n\x06URGENT\x10\x04\x12\r\n\tEMERGENCY\x10\x05\"\"\n\tInitiator\x12\n\n\x06SYSTEM\x10\x00\x12\t\n\x05HUMAN\x10\n\".\n\x06Policy\x12\x0c\n\x08PRESERVE\x10\x00\x12\x0b\n\x07MAXIMUM\x10\n\x12\t\n\x05\x46IRST\x10\x14\x42\x18\x42\x16ResourceAllocationType')
  ,
  dependencies=[rst_dot_timing_dot_Interval__pb2.DESCRIPTOR,])



_RESOURCEALLOCATION_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='rst.communicationpatterns.ResourceAllocation.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUESTED', index=0, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=2, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=3, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLOCATED', index=4, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=5, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELEASED', index=6, number=70,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=553,
  serialized_end=661,
)
_sym_db.RegisterEnumDescriptor(_RESOURCEALLOCATION_STATE)

_RESOURCEALLOCATION_PRIORITY = _descriptor.EnumDescriptor(
  name='Priority',
  full_name='rst.communicationpatterns.ResourceAllocation.Priority',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URGENT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=663,
  serialized_end=739,
)
_sym_db.RegisterEnumDescriptor(_RESOURCEALLOCATION_PRIORITY)

_RESOURCEALLOCATION_INITIATOR = _descriptor.EnumDescriptor(
  name='Initiator',
  full_name='rst.communicationpatterns.ResourceAllocation.Initiator',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HUMAN', index=1, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=741,
  serialized_end=775,
)
_sym_db.RegisterEnumDescriptor(_RESOURCEALLOCATION_INITIATOR)

_RESOURCEALLOCATION_POLICY = _descriptor.EnumDescriptor(
  name='Policy',
  full_name='rst.communicationpatterns.ResourceAllocation.Policy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRESERVE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAXIMUM', index=1, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIRST', index=2, number=20,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=777,
  serialized_end=823,
)
_sym_db.RegisterEnumDescriptor(_RESOURCEALLOCATION_POLICY)


_RESOURCEALLOCATION = _descriptor.Descriptor(
  name='ResourceAllocation',
  full_name='rst.communicationpatterns.ResourceAllocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.communicationpatterns.ResourceAllocation.id', index=0,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.communicationpatterns.ResourceAllocation.state', index=1,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='rst.communicationpatterns.ResourceAllocation.priority', index=2,
      number=30, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initiator', full_name='rst.communicationpatterns.ResourceAllocation.initiator', index=3,
      number=40, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='policy', full_name='rst.communicationpatterns.ResourceAllocation.policy', index=4,
      number=50, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot', full_name='rst.communicationpatterns.ResourceAllocation.slot', index=5,
      number=60, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='rst.communicationpatterns.ResourceAllocation.constraints', index=6,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resource_ids', full_name='rst.communicationpatterns.ResourceAllocation.resource_ids', index=7,
      number=80, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='rst.communicationpatterns.ResourceAllocation.description', index=8,
      number=90, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESOURCEALLOCATION_STATE,
    _RESOURCEALLOCATION_PRIORITY,
    _RESOURCEALLOCATION_INITIATOR,
    _RESOURCEALLOCATION_POLICY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=823,
)

_RESOURCEALLOCATION.fields_by_name['state'].enum_type = _RESOURCEALLOCATION_STATE
_RESOURCEALLOCATION.fields_by_name['priority'].enum_type = _RESOURCEALLOCATION_PRIORITY
_RESOURCEALLOCATION.fields_by_name['initiator'].enum_type = _RESOURCEALLOCATION_INITIATOR
_RESOURCEALLOCATION.fields_by_name['policy'].enum_type = _RESOURCEALLOCATION_POLICY
_RESOURCEALLOCATION.fields_by_name['slot'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
_RESOURCEALLOCATION.fields_by_name['constraints'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
_RESOURCEALLOCATION_STATE.containing_type = _RESOURCEALLOCATION
_RESOURCEALLOCATION_PRIORITY.containing_type = _RESOURCEALLOCATION
_RESOURCEALLOCATION_INITIATOR.containing_type = _RESOURCEALLOCATION
_RESOURCEALLOCATION_POLICY.containing_type = _RESOURCEALLOCATION
DESCRIPTOR.message_types_by_name['ResourceAllocation'] = _RESOURCEALLOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceAllocation = _reflection.GeneratedProtocolMessageType('ResourceAllocation', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCEALLOCATION,
  __module__ = 'rst.communicationpatterns.ResourceAllocation_pb2'
  # @@protoc_insertion_point(class_scope:rst.communicationpatterns.ResourceAllocation)
  ))
_sym_db.RegisterMessage(ResourceAllocation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026ResourceAllocationType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointJerks.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointJerks.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/kinematics/JointJerks.proto\x12\x0erst.kinematics\"\x1f\n\nJointJerks\x12\x11\n\x05jerks\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x10\x42\x0eJointJerksType')
)




_JOINTJERKS = _descriptor.Descriptor(
  name='JointJerks',
  full_name='rst.kinematics.JointJerks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jerks', full_name='rst.kinematics.JointJerks.jerks', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['JointJerks'] = _JOINTJERKS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JointJerks = _reflection.GeneratedProtocolMessageType('JointJerks', (_message.Message,), dict(
  DESCRIPTOR = _JOINTJERKS,
  __module__ = 'rst.kinematics.JointJerks_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.JointJerks)
  ))
_sym_db.RegisterMessage(JointJerks)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016JointJerksType'))
_JOINTJERKS.fields_by_name['jerks'].has_options = True
_JOINTJERKS.fields_by_name['jerks']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/EncodedImage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/EncodedImage.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/vision/EncodedImage.proto\x12\nrst.vision\"\x8b\x01\n\x0c\x45ncodedImage\x12\x33\n\x08\x65ncoding\x18\x02 \x02(\x0e\x32!.rst.vision.EncodedImage.Encoding\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\"8\n\x08\x45ncoding\x12\x07\n\x03PPM\x10\x01\x12\x07\n\x03PNG\x10\x02\x12\x07\n\x03JPG\x10\x03\x12\x07\n\x03JP2\x10\x04\x12\x08\n\x04TIFF\x10\x05\x42\x12\x42\x10\x45ncodedImageType')
)



_ENCODEDIMAGE_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='rst.vision.EncodedImage.Encoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PPM', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPG', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JP2', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIFF', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=129,
  serialized_end=185,
)
_sym_db.RegisterEnumDescriptor(_ENCODEDIMAGE_ENCODING)


_ENCODEDIMAGE = _descriptor.Descriptor(
  name='EncodedImage',
  full_name='rst.vision.EncodedImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='rst.vision.EncodedImage.encoding', index=0,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.vision.EncodedImage.data', index=1,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENCODEDIMAGE_ENCODING,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=185,
)

_ENCODEDIMAGE.fields_by_name['encoding'].enum_type = _ENCODEDIMAGE_ENCODING
_ENCODEDIMAGE_ENCODING.containing_type = _ENCODEDIMAGE
DESCRIPTOR.message_types_by_name['EncodedImage'] = _ENCODEDIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncodedImage = _reflection.GeneratedProtocolMessageType('EncodedImage', (_message.Message,), dict(
  DESCRIPTOR = _ENCODEDIMAGE,
  __module__ = 'rst.vision.EncodedImage_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.EncodedImage)
  ))
_sym_db.RegisterMessage(EncodedImage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020EncodedImageType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/ForceApplication.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dynamics import Forces_pb2 as rst_dot_dynamics_dot_Forces__pb2
from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/ForceApplication.proto',
  package='rst.robot',
  syntax='proto2',
  serialized_pb=_b('\n rst/robot/ForceApplication.proto\x12\trst.robot\x1a\x19rst/dynamics/Forces.proto\x1a\x1erst/geometry/Translation.proto\"{\n\x10\x46orceApplication\x12\x0c\n\x04link\x18\x01 \x02(\t\x12#\n\x05\x66orce\x18\x02 \x02(\x0b\x32\x14.rst.dynamics.Forces\x12\x34\n\x11\x61pplication_point\x18\x03 \x02(\x0b\x32\x19.rst.geometry.TranslationB\x16\x42\x14\x46orceApplicationType')
  ,
  dependencies=[rst_dot_dynamics_dot_Forces__pb2.DESCRIPTOR,rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,])




_FORCEAPPLICATION = _descriptor.Descriptor(
  name='ForceApplication',
  full_name='rst.robot.ForceApplication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='rst.robot.ForceApplication.link', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='force', full_name='rst.robot.ForceApplication.force', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='application_point', full_name='rst.robot.ForceApplication.application_point', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=229,
)

_FORCEAPPLICATION.fields_by_name['force'].message_type = rst_dot_dynamics_dot_Forces__pb2._FORCES
_FORCEAPPLICATION.fields_by_name['application_point'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
DESCRIPTOR.message_types_by_name['ForceApplication'] = _FORCEAPPLICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ForceApplication = _reflection.GeneratedProtocolMessageType('ForceApplication', (_message.Message,), dict(
  DESCRIPTOR = _FORCEAPPLICATION,
  __module__ = 'rst.robot.ForceApplication_pb2'
  # @@protoc_insertion_point(class_scope:rst.robot.ForceApplication)
  ))
_sym_db.RegisterMessage(ForceApplication)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024ForceApplicationType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/flexirob/RobotStateCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.devices.flexirob import RobotState_pb2 as rst_dot_devices_dot_flexirob_dot_RobotState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/flexirob/RobotStateCollection.proto',
  package='rst.devices.flexirob',
  syntax='proto2',
  serialized_pb=_b('\n/rst/devices/flexirob/RobotStateCollection.proto\x12\x14rst.devices.flexirob\x1a%rst/devices/flexirob/RobotState.proto\"I\n\x14RobotStateCollection\x12\x31\n\x07\x65lement\x18\x01 \x03(\x0b\x32 .rst.devices.flexirob.RobotStateB\x1a\x42\x18RobotStateCollectionType')
  ,
  dependencies=[rst_dot_devices_dot_flexirob_dot_RobotState__pb2.DESCRIPTOR,])




_ROBOTSTATECOLLECTION = _descriptor.Descriptor(
  name='RobotStateCollection',
  full_name='rst.devices.flexirob.RobotStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.flexirob.RobotStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=185,
)

_ROBOTSTATECOLLECTION.fields_by_name['element'].message_type = rst_dot_devices_dot_flexirob_dot_RobotState__pb2._ROBOTSTATE
DESCRIPTOR.message_types_by_name['RobotStateCollection'] = _ROBOTSTATECOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotStateCollection = _reflection.GeneratedProtocolMessageType('RobotStateCollection', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTSTATECOLLECTION,
  __module__ = 'rst.devices.flexirob.RobotStateCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.flexirob.RobotStateCollection)
  ))
_sym_db.RegisterMessage(RobotStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030RobotStateCollectionType'))
# @@protoc_insertion_point(module_scope)
